==> munit-runner-1.2.1-sources.jar: org/mule/munit/runner/mule/MunitSuiteRunner.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner.mule;

import org.mule.api.MuleContext;
import org.mule.munit.runner.MuleContextManager;
import org.mule.munit.runner.MunitRunner;
import org.mule.munit.runner.mule.result.SuiteResult;
import org.mule.munit.runner.mule.result.notification.NotificationListener;
import org.mule.munit.runner.output.DefaultOutputHandler;
import org.mule.munit.runner.output.TestOutputHandler;

import java.util.List;


/**
 * <p>
 * The Munit test runner
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 3.3.2
 */
public class MunitSuiteRunner {

    private MuleContext muleContext;
    private MunitSuite suite;
    private TestOutputHandler handler = new DefaultOutputHandler();
    private MuleContextManager muleContextManager = new MuleContextManager(null);


    public MunitSuiteRunner(String resources, List<String> testNameList, String projectName) {
        try {
            muleContext = muleContextManager.startMule(resources, projectName);

            suite = new MunitSuiteBuilder(muleContext, handler).build(resources, testNameList);

        } catch (Exception e) {
            muleContextManager.killMule(muleContext);
            throw new RuntimeException(e);
        }
    }

    public SuiteResult run() {
        return new MunitRunner<SuiteResult>(handler, muleContextManager, muleContext) {

            @Override
            protected SuiteResult runSuite() throws Exception {
                return suite.run();
            }

            @Override
            protected String getSuiteName() {
                return suite.getName();
            }
        }.run();
    }

    public void setNotificationListener(NotificationListener notificationListener) {
        this.suite.setNotificationListener(notificationListener);
    }


    public int getNumberOfTests() {
        return suite.getNumberOfTests();
    }

    public void setHandler(TestOutputHandler handler) {
        this.handler = handler;
    }
}

==> munit-runner-1.3.3-sources.jar: org/mule/munit/runner/mule/MunitSuiteRunner.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner.mule;

import org.mule.api.MuleContext;
import org.mule.munit.runner.MuleContextManager;
import org.mule.munit.runner.MunitRunner;
import org.mule.munit.runner.mule.result.SuiteResult;
import org.mule.munit.runner.mule.result.notification.NotificationListener;
import org.mule.munit.runner.mule.result.notification.SuiteRunnerEventListenerAdapter;
import org.mule.munit.runner.mule.result.notification.SuiteRunnerEventListenerContainer;
import org.mule.munit.runner.output.DefaultOutputHandler;
import org.mule.munit.runner.output.TestOutputHandler;
import org.mule.munit.runner.spring.config.model.MockingConfiguration;

import java.util.List;


/**
 * <p>
 * The Munit test runner
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 3.3.2
 */
public class MunitSuiteRunner {

    private MuleContext muleContext;
    private MunitSuite suite;
    private TestOutputHandler handler = new DefaultOutputHandler();
    private MuleContextManager muleContextManager;

    public MunitSuiteRunner(String resources, List<String> testNameList, String projectName, MockingConfiguration configuration) {
        try {
            //TODO: dds change this so we can inject the mulecontextmanager
            muleContextManager = new MuleContextManager(configuration);
            muleContext = muleContextManager.startMule(resources, projectName);

            suite = new MunitSuiteBuilder(muleContext, handler).build(resources, testNameList);

        } catch (Exception e) {
            muleContextManager.killMule(muleContext);
            throw new RuntimeException(e);
        }
    }

    public MunitSuiteRunner(String resources, List<String> testNameList, String projectName) {
        this(resources, testNameList, projectName, null);
    }

    public SuiteResult run() {
        return new MunitRunner<SuiteResult>(handler, muleContextManager, muleContext) {

            @Override
            protected SuiteResult runSuite() throws Exception {
                return suite.run();
            }

            @Override
            protected String getSuiteName() {
                return suite.getName();
            }
        }.run();
    }

    public void setNotificationListener(NotificationListener notificationListener) {
        this.suite.setSuiteRunnerEventListener(new SuiteRunnerEventListenerAdapter(notificationListener));
    }


    public int getNumberOfTests() {
        return suite.getNumberOfTests();
    }

    public void setHandler(TestOutputHandler handler) {
        this.handler = handler;
    }
}
